@@ -37,7 +37,7 @@ uid_t datauid=0;
 gid_t datagid=0;
 char *invocationname=NULL;
 char *pkgdatadir=NULL;
-char *pkglibdir=NULL;
+char *pkglibexecdir=NULL;
 char *pkgcachedir=NULL;
 char *pkgdatafilesdir=NULL;
 char *pkgdatafilesbindir=NULL;
@@ -92,25 +92,25 @@ char * dupdirname(const char *name) {
  char * foldername=NULL;
  if ((name != NULL) && (*name != '\0')) {
   const char *eofn=name+strlen(name);
-  /*while ((eofn!=name)&&(*(--eofn)=='/')) ;*/
   while ((eofn!=name)&&(*eofn!='/')) --eofn;
+  const char * peofn=eofn;
+  while ((eofn!=name)&&(*(--peofn)=='/')) eofn=peofn;
   if (eofn!=name) {
    const size_t ublofn=eofn-name;
    size_t cdx=0; const char * dim=NULL; char * dam=NULL; int flag=0;
-   foldername=(char *)(malloc(ublofn)); memset(foldername,'\0',ublofn);
+   foldername=(char *)(malloc(ublofn+1)); memset(foldername,'\0',ublofn+1);
    for(cdx=0,dim=name,dam=foldername;cdx<ublofn;++dim,++cdx) {
     if (*dim == '/') flag=1;
     else {if (flag) {*dam='/'; ++dam; flag=0;} *dam=*dim; ++dam;}}
-   if (flag) *dam='/';
    }
   else {foldername=strdup((*name != '/')?".":"/");}}
-	return foldername;}
+ return foldername;}
 
 static void prepare_main(char *argv0)
 {char *env_pkgdir; struct stat infod, infodb, infof; int flag;
  invocationname=argv0;
  env_pkgdir=getenv(SYMPOW_ENV_PKGDATADIR); pkgdatadir=(env_pkgdir!=NULL)?env_pkgdir:PKGDATADIR;
- env_pkgdir=getenv(SYMPOW_ENV_PKGLIBDIR); pkglibdir=(env_pkgdir!=NULL)?env_pkgdir:PKGLIBDIR;
+ env_pkgdir=getenv(SYMPOW_ENV_PKGLIBEXECDIR); pkglibexecdir=(env_pkgdir!=NULL)?env_pkgdir:PKGLIBEXECDIR;
  env_pkgdir=getenv(SYMPOW_ENV_PKGCACHEDIR); pkgcachedir=(env_pkgdir!=NULL)?env_pkgdir:PKGCACHEDIR;
  datauid=getuid();
  if ((cachedir=dupxgetxenvdir(SYMPOW_ENV_CACHEDIR,sizeof(PKGFOLDER),&flag))!=NULL) {
@@ -151,7 +151,7 @@ static void prepare_main(char *argv0)
 	else {pkgdatamode= infodb.st_mode & ~MASK;}}
  asprintf(&datafilesdir,"%s/datafiles",cachedir);
  asprintf(&datafilesbindir,"%s/"ENDIANTUPLE,datafilesdir);
- asprintf(&newdatascript,"%s/new_data",pkglibdir);
+ asprintf(&newdatascript,"%s/new_data",pkglibexecdir);
  asprintf(&paramdatafile,"%s/param_data",datafilesdir);
  if (stat(datafilesdir,&infod))
  {if (stat(cachedir,&infod)) {fprintf(stderr,"**ERROR** cache directory %s does not exist\n",cachedir); exit(-1);}
@@ -209,7 +209,7 @@ static void postpare_main()
  free(datafilesbindir); free(datafilesdir); free(cachedir);
  free(pkgdatafilesbindir);
  if (pkgdatafilesdir) free(pkgdatafilesdir);
- /* free(pkgcachedir); free(pkglibdir); free(pkgdatadir); */
+ /* free(pkgcachedir); free(pkglibexecdir); free(pkgdatadir); */
  /*free(invocationname);*/}
 
 int main(int argc,char **argv)
