@@ -17,7 +17,7 @@
 
 /* mainly for developping usage */
 #define SYMPOW_ENV_PKGDATADIR  "SYMPOW_PKGDATADIR"
-#define SYMPOW_ENV_PKGLIBDIR   "SYMPOW_PKGLIBDIR"
+#define SYMPOW_ENV_PKGLIBEXECDIR   "SYMPOW_PKGLIBEXECDIR"
 #define SYMPOW_ENV_PKGCACHEDIR "SYMPOW_PKGCACHEDIR"
 
 /* internal usage */
@@ -38,8 +38,8 @@
 #ifndef PKGDATADIR
 #define PKGDATADIR PREFIX "/share/" PKGFOLDER
 #endif
-#ifndef PKGLIBDIR
-#define PKGLIBDIR PREFIX "/lib/" PKGFOLDER
+#ifndef PKGLIBEXECDIR
+#define PKGLIBEXECDIR PREFIX "/libexec/" PKGFOLDER
 #endif
 #ifndef PKGCACHEDIR
 #define PKGCACHEDIR VARPREFIX "/cache/" PKGFOLDER
@@ -105,7 +105,7 @@ extern uid_t datauid;
 extern gid_t datagid;
 extern char *invocationname;
 extern char *pkgdatadir;
-extern char *pkglibdir;
+extern char *pkglibexecdir;
 extern char *pkgcachedir;
 extern char *pkgdatafilesdir;
 extern char *pkgdatafilesbindir;
